@@ -175,6 +175,17 @@ def share_extend(request, share_id, new_size):
     return manilaclient(request).shares.extend(share_id, new_size)
 
 
+def share_revert(request, share, snapshot):
+    """Sends request to revert share to specific snapshot.
+
+    This API available only since 2.27 microversion.
+
+    :param share: Share class instance or share ID
+    :param snapshot: ShareSnapshot class instance or share snapshot ID
+    """
+    return manilaclient(request).shares.revert_to_snapshot(share, snapshot)
+
+
 def share_snapshot_get(request, snapshot_id):
     return manilaclient(request).share_snapshots.get(snapshot_id)
 
@@ -329,7 +340,20 @@ def tenant_quota_get(request, tenant_id):
     return base.QuotaSet(manilaclient(request).quotas.get(tenant_id))
 
 
+def _map_quota_names_for_update(data):
+    mapping = {
+        'share_gigabytes': 'gigabytes',
+        'share_snapshots': 'snapshots',
+        'share_snapshot_gigabytes': 'snapshot_gigabytes',
+    }
+    for k, v in mapping.items():
+        if k in data:
+            data[v] = data.pop(k)
+    return data
+
+
 def tenant_quota_update(request, tenant_id, **kwargs):
+    _map_quota_names_for_update(kwargs)
     return manilaclient(request).quotas.update(tenant_id, **kwargs)
 
 
@@ -338,6 +362,7 @@ def default_quota_get(request, tenant_id):
 
 
 def default_quota_update(request, **kwargs):
+    _map_quota_names_for_update(kwargs)
     manilaclient(request).quota_classes.update(DEFAULT_QUOTA_NAME, **kwargs)
 
 
